summaryrefslogtreecommitdiff
path: root/indoteknik_custom/models/purchase_pricelist.py
diff options
context:
space:
mode:
Diffstat (limited to 'indoteknik_custom/models/purchase_pricelist.py')
-rwxr-xr-xindoteknik_custom/models/purchase_pricelist.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/indoteknik_custom/models/purchase_pricelist.py b/indoteknik_custom/models/purchase_pricelist.py
index c543070a..e5b35d7f 100755
--- a/indoteknik_custom/models/purchase_pricelist.py
+++ b/indoteknik_custom/models/purchase_pricelist.py
@@ -48,9 +48,9 @@ class PurchasePricelist(models.Model):
def _constrains_include_price(self):
price, taxes = self._get_valid_price()
# When have tax is excluded or empty tax, then multiply by 1.12
if (taxes and not taxes.price_include) or not taxes:
- price *= 1.12
+ price *= 1.11
self.include_price = price
@@ -48,9 +48,9 @@ class PurchasePricelist(models.Model):
def _constrains_include_price(self):
price, taxes = self._get_valid_price()
- # When have tax is excluded or empty tax, then multiply by 1.12
+ # When have tax is excluded or empty tax, then multiply by 1.11
if (taxes and not taxes.price_include) or not taxes: